@@ -1,12 +1,8 @@
 package Minion::Backend::Storable;
 use Minion::Backend -base;
 
-our $VERSION = 5.091;
+our $VERSION = 6.051;
 
-use IO::Compress::Gzip 'gzip';
-use IO::Uncompress::Gunzip 'gunzip';
-use List::Util 'first';
-use Storable qw(freeze thaw);
 use Sys::Hostname 'hostname';
 use Time::HiRes qw(time usleep);
 
@@ -16,6 +12,20 @@ has 'file';
 
 # Methods
 
+sub broadcast {
+  my ($self, $command, $args, $ids) = (shift, shift, shift || [], shift || []);
+
+  my $guard = $self->_guard->_write;
+  my $inboxes = $guard->_inboxes;
+  my $workers = $guard->_workers;
+  @$ids = @$ids ? map exists($workers->{$_}), @$ids
+      : keys %$workers unless @$ids;
+
+  push @{$inboxes->{$_} ||= []}, [$command, @$args] for @$ids;
+
+  return !!@$ids;
+}
+
 sub dequeue {
   my ($self, $id, $wait, $options) = @_;
   usleep $wait * 1_000_000 unless my $job = $self->_try($id, $options);
@@ -81,15 +91,24 @@ sub list_workers {
 
 sub new { shift->SUPER::new(file => shift) }
 
-sub register_worker {
+sub receive {
   my ($self, $id) = @_;
   my $guard = $self->_guard->_write;
+  my $inboxes = $guard->_inboxes;
+  my $inbox = $inboxes->{$id} || [];
+  $inboxes->{$id} = [];
+  return $inbox;
+}
+
+sub register_worker {
+  my ($self, $id, $options) = (shift, shift, shift || {});
+  my $guard = $self->_guard->_write;
   my $worker = $id ? $guard->_workers->{$id} : undef;
   unless ($worker) {
     $worker = {host => hostname, id => $guard->_id, pid => $$, started => time};
     $guard->_workers->{$worker->{id}} = $worker;
   }
-  $worker->{notified} = time;
+  @$worker{qw(notified status)} = (time, $options->{status} || {});
   return $worker->{id};
 }
 
@@ -147,7 +166,8 @@ sub retry_job {
   my ($self, $id, $retries, $options) = (shift, shift, shift, shift || {});
 
   my $guard = $self->_guard;
-  return undef unless my $job = $guard->_job($id, 'inactive', 'failed', 'finished');
+  return undef
+    unless my $job = $guard->_job($id, qw(active failed finished inactive));
   return undef unless $job->{retries} == $retries;
   $guard->_write;
   ++$job->{retries};
@@ -184,22 +204,17 @@ sub stats {
   };
 }
 
-sub unregister_worker { delete shift->_guard->_write->_workers->{shift()} }
+sub unregister_worker {
+  my ($self, $id) = @_;
+  my $guard = $self->_guard->_write;
+  delete $guard->_inboxes->{$id};
+  delete $guard->_workers->{$id};
+}
 
 sub worker_info { $_[0]->_worker_info($_[0]->_guard, $_[1]) }
 
-sub _deserialize {
-  gunzip \(my $compressed = shift), \my $uncompressed;
-  return thaw $uncompressed;
-}
-
 sub _guard { Minion::Backend::Storable::_Guard->new(backend => shift) }
 
-sub _serialize {
-  gzip \(my $uncompressed = freeze(pop)), \my $compressed;
-  return $compressed;
-}
-
 sub _try {
   my ($self, $id, $options) = @_;
   my $tasks = $self->minion->tasks;
@@ -294,10 +309,12 @@ sub _id {
   return $id;
 }
 
+sub _inboxes { shift->_data->{inboxes} ||= {} }
+
 sub _job {
   my ($self, $id) = (shift, shift);
   return undef unless my $job = $self->_jobs->{$id};
-  return(grep(+($job->{state} eq $_), @_) ? $job : undef);
+  return(grep(($job->{state} eq $_), @_) ? $job : undef);
 }
 
 sub _job_id {
@@ -338,9 +355,7 @@ Minion::Backend::Storable - File backend for Minion job queues.
 L<Minion::Backend::Storable> is a highly portable file-based backend for
 L<Minion>.
 
-CAVEAT: this version is only compatible with Minion v5.
-
-  cpanm -l dep Minion@5.09
+This version supports Minion v6.06.
 
 =head1 ATTRIBUTES
 
@@ -440,7 +455,7 @@ L<Minion/"backoff"> after the first attempt, defaults to C<1>.
 
   delay => 10
 
-Delay job for this many seconds (from now).
+Delay job for this many seconds (from now), defaults to C<0>.
 
 =item parents
 
@@ -453,7 +468,8 @@ transitioned to the state C<finished> before it can be processed.
 
   priority => 5
 
-Job priority, defaults to C<0>.
+Job priority, defaults to C<0>.  Jobs with a higher priority get performed
+first.
 
 =item queue
 
@@ -648,9 +664,23 @@ Receive remote control commands for worker.
 
   my $worker_id = $backend->register_worker;
   my $worker_id = $backend->register_worker($worker_id);
+  my $worker_id = $backend->register_worker(
+      $worker_id, {status => {queues => ['default', 'important']}});
 
 Register worker or send heartbeat to show that this worker is still alive.
 
+These options are currently available:
+
+=over 2
+
+=item status
+
+  status => {queues => ['default', 'important']}
+
+Hash reference with whatever status information the worker would like to share.
+
+=back
+
 =head2 remove_job
 
   my $bool = $backend->remove_job($job_id);
@@ -674,8 +704,8 @@ Reset job queue.
   my $bool = $backend->retry_job($job_id, $retries);
   my $bool = $backend->retry_job($job_id, $retries, {delay => 10});
 
-Transition from C<failed> or C<finished> state back to C<inactive>, already
-C<inactive> jobs may also be retried to change options.
+Transition job back to C<inactive> state, already C<inactive> jobs may also be
+retried to change options.
 
 These options are currently available:
 
@@ -685,7 +715,7 @@ These options are currently available:
 
   delay => 10
 
-Delay job for this many seconds (from now).
+Delay job for this many seconds (from now), defaults to C<0>.
 
 =item priority
 
@@ -728,15 +758,15 @@ Number of workers that are currently processing a job.
   delayed_jobs => 100
 
 Number of jobs in C<inactive> state that are scheduled to run at specific time
-in the future or have unresolved dependencies. Note that this field is
+in the future or have unresolved dependencies.  Note that this field is
 EXPERIMENTAL and might change without warning!
 
 =item enqueued_jobs
 
   enqueued_jobs => 100000
 
-Rough estimate of how many jobs have ever been enqueued. Note that this field is
-EXPERIMENTAL and might change without warning!
+Rough estimate of how many jobs have ever been enqueued.  Note that this field
+is EXPERIMENTAL and might change without warning!
 
 =item failed_jobs
 
@@ -813,13 +843,19 @@ Process id of worker.
 
 Epoch time worker was started.
 
+=item status
+
+  status => {queues => ['default', 'important']}
+
+Hash reference with whatever status information the worker would like to share.
+
 =back
 
 =head1 COPYRIGHT AND LICENCE
 
 Copyright (c) 2014 Sebastian Riedel.
 
-Copyright (c) 2015--2016 Sebastian Riedel & Nic Sandfield.
+Copyright (c) 2015--2017 Sebastian Riedel & Nic Sandfield.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Artistic License version 2.0.
